@@ -1,22 +1,60 @@
-from pathlib import Path
-from typing import Tuple, Dict, List, Iterable, Optional, Any, Pattern
-
-import click
+import os
 import re
+from pathlib import Path
+import sys
+import textwrap
+from typing import Any, Dict, List, Optional, Pattern, Tuple, Union
+
+import rich_click as click
+from rich.markdown import Markdown
 
 from robotidy.app import Robotidy
+from robotidy.console import console
+from robotidy.decorators import catch_exceptions
+from robotidy.files import DEFAULT_EXCLUDES, find_and_read_config, read_pyproject_config
 from robotidy.transformers import load_transformers
-from robotidy.files import read_pyproject_config, find_and_read_config, DEFAULT_EXCLUDES
 from robotidy.utils import (
     GlobalFormattingConfig,
-    split_args_from_name_or_path,
-    remove_rst_formatting,
     RecommendationFinder,
+    ROBOT_VERSION,
+    TargetVersion,
+    split_args_from_name_or_path,
 )
-from robotidy.decorators import catch_exceptions
 from robotidy.version import __version__
 
 
+COLOR_SYSTEM = "auto"
+click.rich_click.USE_MARKDOWN = True
+click.rich_click.OPTION_GROUPS = {
+    "robotidy": [
+        {
+            "name": "Run only selected transformers",
+            "options": ["--transform"],
+        },
+        {
+            "name": "Work modes",
+            "options": ["--overwrite", "--diff", "--check", "--force-order"],
+        },
+        {
+            "name": "Documentation",
+            "options": ["--list", "--desc"],
+        },
+        {
+            "name": "Configuration",
+            "options": ["--configure", "--config"],
+        },
+        {
+            "name": "Global formatting settings",
+            "options": ["--spacecount", "--line-length", "--lineseparator", "--separator", "--startline", "--endline"],
+        },
+        {"name": "File exclusion", "options": ["--exclude", "--extend-exclude"]},
+        {
+            "name": "Other",
+            "options": ["--target-version", "--verbose", "--color", "--output", "--version", "--help"],
+        },
+    ],
+}
+
 CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
 HELP_MSG = f"""
 Version: {__version__}
@@ -26,42 +64,37 @@ See examples at the end of this help message too see how you can use Robotidy.
 Full documentation available at https://robotidy.readthedocs.io .
 """
 EPILOG = """
-Examples:
-  # Format `path/to/src.robot` file
-  $ robotidy path/to/src.robot
+Examples:\n\n
+# Format `path/to/src.robot` file\n
+$ robotidy path/to/src.robot
 
-  # Format every Robot Framework file inside `dir_name` directory
-  $ robotidy dir_name
 
-  # List available transformers:
-  $ robotidy --list
-  
-  # Display transformer documentation
-  $ robotidy --desc <TRANSFORMER_NAME>
+# Format every Robot Framework file inside `dir_name` directory
 
-  # Format `src.robot` file using `SplitTooLongLine` transformer only
-  $ robotidy --transform SplitTooLongLine src.robot
+$ robotidy dir_name
 
-  # Format `src.robot` file using `SplitTooLongLine` transformer only and configured line length 140
-  $ robotidy --transform SplitTooLongLine:line_length=140 src.robot
 
+# List available transformers:
+
+$ robotidy --list
+
+
+# Display transformer documentation
+
+$ robotidy --desc <TRANSFORMER_NAME>
+
+
+# Format `src.robot` file using `SplitTooLongLine` transformer only
+
+$ robotidy --transform SplitTooLongLine src.robot
+
+
+# Format `src.robot` file using `SplitTooLongLine` transformer only and configured line length 140
+
+$ robotidy --transform SplitTooLongLine:line_length=140 src.robot
 """
 
 
-class RawHelp(click.Command):
-    def format_help_text(self, ctx, formatter):
-        if self.help:
-            formatter.write_paragraph()
-            for line in self.help.split("\n"):
-                formatter.write_text(line)
-
-    def format_epilog(self, ctx, formatter):
-        if self.epilog:
-            formatter.write_paragraph()
-            for line in self.epilog.split("\n"):
-                formatter.write_text(line)
-
-
 class TransformType(click.ParamType):
     name = "transform"
 
@@ -117,6 +150,21 @@ def validate_regex_callback(
     return validate_regex(value)
 
 
+def validate_target_version(
+    ctx: click.Context,
+    param: Union[click.Option, click.Parameter],
+    value: Optional[str],
+) -> Optional[int]:
+    if value is None:
+        return ROBOT_VERSION.major
+    version = TargetVersion[value.upper()].value
+    if version > ROBOT_VERSION.major:
+        raise click.BadParameter(
+            f"Target Robot Framework version ({version}) should not be higher than installed version ({ROBOT_VERSION})."
+        )
+    return version
+
+
 def validate_regex(value: Optional[str]) -> Optional[Pattern]:
     try:
         return re.compile(value) if value is not None else None
@@ -124,16 +172,21 @@ def validate_regex(value: Optional[str]) -> Optional[Pattern]:
         raise click.BadParameter("Not a valid regular expression")
 
 
-def print_description(name: str):
-    transformers = load_transformers(None, {}, allow_disabled=True)
+def print_transformer_docs(name, transformer):
+    documentation = f"## Transformer {name}\n" + textwrap.dedent(transformer.__doc__)
+    documentation += f"\nSee <https://robotidy.readthedocs.io/en/latest/transformers/{name}.html> for more examples."
+    md = Markdown(documentation, code_theme="native", inline_code_lexer="robotframework")
+    console.print(md)
+
+
+def print_description(name: str, target_version: int):
+    transformers = load_transformers(None, {}, allow_disabled=True, target_version=target_version)
     transformer_by_names = {transformer.__class__.__name__: transformer for transformer in transformers}
     if name == "all":
         for tr_name, transformer in transformer_by_names.items():
-            click.echo(f"Transformer {tr_name}:")
-            click.echo(remove_rst_formatting(transformer.__doc__))
+            print_transformer_docs(tr_name, transformer)
     elif name in transformer_by_names:
-        click.echo(f"Transformer {name}:")
-        click.echo(remove_rst_formatting(transformer_by_names[name].__doc__))
+        print_transformer_docs(name, transformer_by_names[name])
     else:
         rec_finder = RecommendationFinder()
         similar = rec_finder.find_similar(name, transformer_by_names.keys())
@@ -142,23 +195,31 @@ def print_description(name: str):
     return 0
 
 
-def print_transformers_list():
-    transformers = load_transformers(None, {}, allow_disabled=True)
-    click.echo(
-        "To see detailed docs run --desc <transformer_name> or --desc all. "
-        "Transformers with (disabled) tag \nare executed only when selected explicitly with --transform or "
-        "configured with param `enabled=True`.\n"
-        "Available transformers:\n"
-    )
+def print_transformers_list(target_version: int):
+    from rich.table import Table
+
+    table = Table(title="Transformers", header_style="bold red")
+    table.add_column("Name", justify="left", no_wrap=True)
+    table.add_column("Enabled by default")
+    transformers = load_transformers(None, {}, allow_disabled=True, target_version=target_version)
     transformer_names = []
     for transformer in transformers:
-        disabled = " (disabled)" if not getattr(transformer, "ENABLED", True) else ""
-        transformer_names.append(transformer.__class__.__name__ + disabled)
-    for name in sorted(transformer_names):
-        click.echo(name)
+        enabled = "[bold magenta]No" if not getattr(transformer, "ENABLED", True) else "Yes"
+        transformer_names.append([transformer.__class__.__name__, enabled])
+    for name, enabled in sorted(transformer_names):
+        table.add_row(name, enabled)
+    console.print(table)
+    console.print(
+        "To see detailed docs run:\n"
+        "    [bold]robotidy --desc [bold magenta]transformer_name[/][/]\n"
+        "or\n"
+        "    [bold]robotidy --desc [bold blue]all[/][/]\n\n"
+        "Non-default transformers needs to be selected explicitly with [bold cyan]--transform[/] or "
+        "configured with param `enabled=True`.\n"
+    )
 
 
-@click.command(cls=RawHelp, help=HELP_MSG, epilog=EPILOG, context_settings=CONTEXT_SETTINGS)
+@click.command(context_settings=CONTEXT_SETTINGS)  # epilog=EPILOG,
 @click.option(
     "--transform",
     "-t",
@@ -229,6 +290,12 @@ def print_transformers_list():
     help="Output diff of each processed file.",
     show_default=True,
 )
+@click.option(
+    "--color/--no-color",
+    default=True,
+    help="Enable ANSI coloring the output",
+    show_default=True,
+)
 @click.option(
     "--check",
     is_flag=True,
@@ -309,7 +376,7 @@ def print_transformers_list():
     type=click.Path(file_okay=True, dir_okay=False, writable=True, allow_dash=False),
     default=None,
     metavar="PATH",
-    help="Path to output file where source file will be saved",
+    help="Use this option to override file destination path.",
 )
 @click.option("-v", "--verbose", is_flag=True, help="More verbose output", show_default=True)
 @click.option(
@@ -317,6 +384,13 @@ def print_transformers_list():
     is_flag=True,
     help="Transform files using transformers in order provided in cli",
 )
+@click.option(
+    "--target-version",
+    "-t",
+    type=click.Choice([v.name.lower() for v in TargetVersion], case_sensitive=False),
+    callback=validate_target_version,
+    help="Only enable transformers supported in set target version. [default: installed Robot Framework version]",
+)
 @click.version_option(version=__version__, prog_name="robotidy")
 @click.pass_context
 @catch_exceptions
@@ -329,6 +403,7 @@ def cli(
     extend_exclude: Optional[Pattern],
     overwrite: bool,
     diff: bool,
+    color: bool,
     check: bool,
     spacecount: int,
     lineseparator: str,
@@ -342,19 +417,26 @@ def cli(
     desc: Optional[str],
     output: Optional[Path],
     force_order: bool,
+    target_version: int,
 ):
+    """
+    Robotidy is a tool for formatting Robot Framework source code.
+
+    See examples at the end of this help message too see how you can use Robotidy.
+    Full documentation available at https://robotidy.readthedocs.io .
+    """
     if list:
-        print_transformers_list()
-        ctx.exit(0)
+        print_transformers_list(target_version)
+        sys.exit(0)
     if desc is not None:
-        return_code = print_description(desc)
-        ctx.exit(return_code)
+        return_code = print_description(desc, target_version)
+        sys.exit(return_code)
     if not src:
         if ctx.default_map is not None:
             src = ctx.default_map.get("src", None)
         if not src:
             print("No source path provided. Run robotidy --help to see how to use robotidy")
-            ctx.exit(1)
+            sys.exit(1)
 
     if exclude is None:
         exclude = re.compile(DEFAULT_EXCLUDES)
@@ -366,6 +448,9 @@ def cli(
         # None is default, with check not set -> overwrite, with check set -> overwrite only when overwrite flag is set
         overwrite = not check
 
+    if color:
+        color = "NO_COLOR" not in os.environ
+
     formatting_config = GlobalFormattingConfig(
         space_count=spacecount,
         line_sep=lineseparator,
@@ -387,6 +472,8 @@ def cli(
         check=check,
         output=output,
         force_order=force_order,
+        target_version=target_version,
+        color=color,
     )
     status = tidy.transform_files()
-    ctx.exit(status)
+    sys.exit(status)
