@@ -1,7 +1,8 @@
 from typing import Optional
 
-from robot.api.parsing import ModelTransformer, EmptyLine, Token
+from robot.api.parsing import EmptyLine, ModelTransformer, Token
 
+from robotidy.disablers import skip_section_if_disabled
 from robotidy.utils import is_suite_templated
 
 
@@ -21,15 +22,13 @@ class NormalizeNewLines(ModelTransformer):
 
     If the suite contains Test Template tests will not be separated by empty lines unless ``separate_templated_tests``
     is set to True.
-
-    See https://robotidy.readthedocs.io/en/latest/transformers/NormalizeNewLines.html for more examples.
     """
 
     def __init__(
         self,
         test_case_lines: int = 1,
         keyword_lines: Optional[int] = None,
-        section_lines: int = 1,
+        section_lines: int = 2,
         separate_templated_tests: bool = False,
         consecutive_lines: int = 1,
     ):
@@ -48,6 +47,7 @@ class NormalizeNewLines(ModelTransformer):
         self.last_section = node.sections[-1] if node.sections else None
         return self.generic_visit(node)
 
+    @skip_section_if_disabled
     def visit_Section(self, node):  # noqa
         self.trim_empty_lines(node)
         empty_line = EmptyLine.from_params()
@@ -76,6 +76,12 @@ class NormalizeNewLines(ModelTransformer):
             node.body.extend([EmptyLine.from_params()] * self.keyword_lines)
         return self.generic_visit(node)
 
+    def visit_If(self, node):  # noqa
+        self.trim_empty_lines(node)
+        return self.generic_visit(node)
+
+    visit_For = visit_While = visit_Try = visit_If
+
     def visit_Statement(self, node):  # noqa
         tokens = []
         for line in node.lines:
